#
# spec file for package kew
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kew
Version:        2.2.1
Release:        1.1
Summary:        A command-line music player
License:        GPL-2.0-only
URL:            https://github.com/ravachol/kew
Source:         %{url}/archive/v%{version}/kew-%{version}.tar.gz
BuildRequires:  freeimage-devel
BuildRequires:  gcc >= 13
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(chafa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(vorbisfile)

%description
Listen to music in the terminal.

%prep
%autosetup

%build
%make_build

%install
%make_install

%files
%license LICENSE
%doc README*
%{_bindir}/kew
%{_mandir}/man1/kew.1%{?ext_man}

%changelog
* Sat Feb  3 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.2.1
  * Fixed issue related to enqueuing/dequeuing the next song.
* Sat Feb  3 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.2
  * This update mostly contains improvements to stability.
  * M4a file decoding is no longer done by calling ffmpeg
    externally, it's (finally) done like the other file formats.
    This should make kew more stable, responsive and it should
    consume less memory when playing m4a files.
  * kew now starts the first time with your system volume as the
    volume, after that it remembers the last volume it exited with
    and uses that.
  * kew now picks up and starts using the cover color without the
    user having to first go to track view.
* Fri Jan 26 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.1.1
  * Fixed a few issues related to passing cover art url and track
    length to mpris. Should now display cover and progress
    correctly in widgets on gnome/wayland.
* Mon Jan 22 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.4
  * You can now add "-e" or "--exact" in your searches to return an
    exact (not case sensitive) match. This can be helpful when two
    albums have a similar name, and you want to specify you want
    one or the other. Example: kew -e basement popstar.
  * Fixed issue where pressing del on the playlist changed view to
    track view.
* Mon Jan 15 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.3
  * Fixed issue where sometimes the last of enqueued songs where
    being played instead of the first.
  * F4 is bound to show track view, and shown on the last row, so
    that the track view isn't hidden from new users.
* Fri Jan 12 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.2
  * moved mutex initialization code
  * small graphical tweaks
  * show songs before enqueueing everthing
* Thu Jan 11 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.1
  * New view: Library. Shows the contents of the music library.
    From there you can add songs to the playlist.
  * Delete items from the playlist by pressing Del.
  * You can flip through pages of the library or playlist by
    pressing Page Up and Page Down.
  * Starting kew with no arguments now takes you to the library.
  * After the playlist finishes playing, the library is shown,
    instead of the app exiting.
  * To run kew with all songs shuffled like you could before, just
    type "kew all" in the terminal.
  * Running kew with the argument --quitonstop, enables the old
    behavior of exiting when finished.
  * Removed the playlist duration counter. It caused problems when
    coupled with the new features of being able to remove and add
    songs while audio is playing.
  * New ascii logo! This one takes up much less space.
  * kew now shows which song is playing on top of the library and
    playlist views.
  * Volume is now set at 50%% at the start.
  * Also many bug fixes.
* Sun Dec 10 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.11
  * Now shows volume percentage. New alternate key for raising
    volume: =.
  * Fixed bug where on a small window size, the Nerd Fonts for
    seeking, repeat and shuffle when all three enabled could mess
    up the visualizer.
* Mon Dec  4 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.10
  * Improved config file, with more information on how to make key
    bindings with special keys for instance.
  * Changing the volume is now for just kew, not the master volume
    of your system.
  * Switching songs now unpauses the player.
  * Fixed issue of potential crash when uninitializing decoders.
* Fri Dec  1 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.9
  * Fixed a potential dead-lock situation.
  * Fixed one instance of wrong metadata/cover being displayed for
    a song on rare occasions.
  * Fixed an issue that could lead to a crash when switching songs.
  * Fixed issue of potential crash when closing audio file.
  * Fixed playlist showing the previous track as the current one.
  * Much improved memory allocation handling in visualizer.
  * Playlist builder now ignores hidden directories.
* Wed Nov 29 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.8.1
  * Fixed bug where kew for no reason stopped playing audio but
    kept counting elapsed seconds.
  * Fixed bugs relating to showing the playlist.
  * Fixed bug where trying to seek in ogg files led to strange
    behavior. Now seeking in ogg is entirely disabled.
  * More colorful visualizer bars when using album cover colors.
* Tue Nov 28 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.8
  * visualizer bars now grow and decrease smoothly (if your
    terminal supports unicode).
  * m4a files quit properly.
* Mon Nov 27 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.4
  * kew is now interactive when paused.
  * Fixed issue with crashing after a few plays with repeat
    enabled.
  * Deletes cover images from cache after playing the file.
* Sun Nov 26 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.3
  * Fixed issue with crashing after a few plays with repeat
    enabled.
  * Fixed issue with crash after seeking to the end of songs a few
    times.
* Thu Nov 23 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.2
  * Introduced Nerd Font glyphs for things like pause, repeat, fast
    forward and so on.
  * More minor fixes.
  * Fixed issues with the makefile.
* Mon Nov 20 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.1
  * Fixes a few issues in 1.7.0
* Fri Nov 17 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
